/* This file is part of the KDE libraries
    Copyright (C) 2004 Felix Berger <felixberger@beldesign.de>
    
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/

#include "ktoolbarlabelaction.h"

#include <qlabel.h>
#include <qapplication.h>

KToolBarLabelAction::KToolBarLabelAction(const QString &text,
					 const KShortcut &cut,
					 const QObject *receiver, 
					 const char *slot,
					 KActionCollection *parent,
					 const char *name)
  : KWidgetAction(new QLabel(text, 0, "kde toolbar widget"), text, cut,
		  receiver, slot, parent, name)
{
  init();
}

KToolBarLabelAction::KToolBarLabelAction(QWidget* buddy, 
					 const QString &text,
					 const KShortcut &cut,
					 const QObject *receiver, 
					 const char *slot,
 					 KActionCollection *parent, 
					 const char *name)
  : KWidgetAction(new QLabel(buddy, text, 0, "kde toolbar widget"), text, 
		  cut, receiver, slot, parent, name)
{
  init();
}

KToolBarLabelAction::KToolBarLabelAction(QLabel* label, 
					 const KShortcut &cut, 
					 const QObject *receiver,
					 const char *slot,
					 KActionCollection* parent, 
					 const char *name)
  : KWidgetAction(label, label->text(), cut, receiver, slot, parent, name)
{
  label->setName("kde toolbar widget");
  init();
}

KToolBarLabelAction::~KToolBarLabelAction()
{
  delete m_label;
  m_label = 0;
}

void KToolBarLabelAction::init()
{
  m_label = static_cast<QLabel*>(widget());
  m_label->setBackgroundMode(Qt::PaletteButton);
  m_label->setAlignment((QApplication::reverseLayout()
		       ? Qt::AlignRight : Qt::AlignLeft) |
	      Qt::AlignVCenter | Qt::ShowPrefix );
  m_label->adjustSize();
}

void KToolBarLabelAction::setText(const QString& text)
{
  KWidgetAction::setText(text);
  m_label->setText(text);
}


void KToolBarLabelAction::setBuddy(QWidget* buddy)
{
  m_label->setBuddy(buddy);
}


QWidget* KToolBarLabelAction::buddy() const
{
  return m_label->buddy();
}

QLabel* KToolBarLabelAction::label() const
{
  return m_label;
}
